.. libjuju documentation master file, created by
   sphinx-quickstart on Thu May 19 11:21:38 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. include:: readme.rst


Table of Contents
-----------------

.. toctree::
   :caption: Overview
   :glob:
   :maxdepth: 3

   narrative/index


.. toctree::
   :caption: API Documentation
   :glob:
   :maxdepth: 3

   api/modules
   api/juju.client

.. toctree::
   :caption: Project
   :glob:
   :maxdepth: 3

   upstream-updates/index
   changelog



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

